@@ -24,11 +24,12 @@
 #ifndef RK_GLOBAL_H
 #define RK_GLOBAL_H
 
-#define RK_VERSION 0x010003
+#define RK_VERSION 0x010200
 #define RK_MAJOR   0x01
-#define RK_MINOR   0x00
-#define RK_PATCH   0x03
+#define RK_MINOR   0x02
+#define RK_PATCH   0x00
 
+#include <utility>
 #include <memory>
 #include <vector>
 #include <string>
@@ -99,14 +100,6 @@ using rk_real = double;
 #endif // RK_SINGLE_PRECISION
 
 namespace Rk {
-        struct RkEnumClassHash {
-                template <typename T>
-                int operator()(T t) const
-                {
-                        return static_cast<int>(t);
-                }
-        };
-
         enum class Alignment : int {
                 AlignLeft   = 1,
                 AlignRight  = 2,
